==> wast-diz-0.3.0.tgz: package/results/f64.js <==
{
  kind: 'script',
  body: [
    {
      kind: 'Magic',
      data: '6d736100'
    },
    {
      kind: 'Version',
      data: '11'
    },
    [{
      kind: 'section',
      name: 'type',
      body: '02 40 02 04 04 01 04 40 01 04 01 04 '
    }],
    [{
      kind: 'section',
      name: 'function',
      body: '0e 00 00 00 00 01 00 00 01 01 01 01 01 01 00 '
    }],
    [{
      kind: 'section',
      name: 'memory',
      body: '00 ff ff 03 00 '
    }],
    [
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'add'
        },
        id: {
          kind: 'identifier',
          name: 0
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'sub'
        },
        id: {
          kind: 'identifier',
          name: 1
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'mul'
        },
        id: {
          kind: 'identifier',
          name: 2
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'div'
        },
        id: {
          kind: 'identifier',
          name: 3
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'sqrt'
        },
        id: {
          kind: 'identifier',
          name: 4
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'min'
        },
        id: {
          kind: 'identifier',
          name: 5
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'max'
        },
        id: {
          kind: 'identifier',
          name: 6
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'ceil'
        },
        id: {
          kind: 'identifier',
          name: 7
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'floor'
        },
        id: {
          kind: 'identifier',
          name: 8
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'trunc'
        },
        id: {
          kind: 'identifier',
          name: 9
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'nearest'
        },
        id: {
          kind: 'identifier',
          name: 10
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'abs'
        },
        id: {
          kind: 'identifier',
          name: 11
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'neg'
        },
        id: {
          kind: 'identifier',
          name: 12
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'copysign'
        },
        id: {
          kind: 'identifier',
          name: 13
        }
      }
    ],
    [
      {
        index: 0,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'add'
          }
        ]
      },
      {
        index: 1,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'sub'
          }
        ]
      },
      {
        index: 2,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'mul'
          }
        ]
      },
      {
        index: 3,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'div'
          }
        ]
      },
      {
        index: 4,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'sqrt'
          }
        ]
      },
      {
        index: 5,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'min'
          }
        ]
      },
      {
        index: 6,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'max'
          }
        ]
      },
      {
        index: 7,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'ceil'
          }
        ]
      },
      {
        index: 8,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'floor'
          }
        ]
      },
      {
        index: 9,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'trunc'
          }
        ]
      },
      {
        index: 10,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'nearest'
          }
        ]
      },
      {
        index: 11,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'abs'
          }
        ]
      },
      {
        index: 12,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'unop',
            type: 'f64',
            operator: 'neg'
          }
        ]
      },
      {
        index: 13,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'nop:0',
          {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          'block:1',
          {
            kind: 'binop',
            type: 'f64',
            operator: 'copysign'
          }
        ]
      }
    ],
    [
      {
        kind: 'name',
        id: 0,
        name: 'add'
      },
      {
        kind: 'name',
        id: 1,
        name: 'sub'
      },
      {
        kind: 'name',
        id: 2,
        name: 'mul'
      },
      {
        kind: 'name',
        id: 3,
        name: 'div'
      },
      {
        kind: 'name',
        id: 4,
        name: 'sqrt'
      },
      {
        kind: 'name',
        id: 5,
        name: 'min'
      },
      {
        kind: 'name',
        id: 6,
        name: 'max'
      },
      {
        kind: 'name',
        id: 7,
        name: 'ceil'
      },
      {
        kind: 'name',
        id: 8,
        name: 'floor'
      },
      {
        kind: 'name',
        id: 9,
        name: 'trunc'
      },
      {
        kind: 'name',
        id: 10,
        name: 'nearest'
      },
      {
        kind: 'name',
        id: 11,
        name: 'abs'
      },
      {
        kind: 'name',
        id: 12,
        name: 'neg'
      },
      {
        kind: 'name',
        id: 13,
        name: 'copysign'
      }
    ]
  ]
}

==> wast-diz-0.4.0.tgz: package/results/f64.js <==
{
  kind: 'script',
  body: [
    {
      kind: 'Magic',
      data: '6d736100'
    },
    {
      kind: 'Version',
      data: '11'
    },
    [{
      kind: 'section',
      name: 'type',
      body: '02 40 02 04 04 01 04 40 01 04 01 04 '
    }],
    [{
      kind: 'section',
      name: 'function',
      body: '0e 00 00 00 00 01 00 00 01 01 01 01 01 01 00 '
    }],
    [{
      kind: 'section',
      name: 'memory',
      body: '00 ff ff 03 00 '
    }],
    [
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'add'
        },
        id: {
          kind: 'identifier',
          name: 0
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'sub'
        },
        id: {
          kind: 'identifier',
          name: 1
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'mul'
        },
        id: {
          kind: 'identifier',
          name: 2
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'div'
        },
        id: {
          kind: 'identifier',
          name: 3
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'sqrt'
        },
        id: {
          kind: 'identifier',
          name: 4
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'min'
        },
        id: {
          kind: 'identifier',
          name: 5
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'max'
        },
        id: {
          kind: 'identifier',
          name: 6
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'ceil'
        },
        id: {
          kind: 'identifier',
          name: 7
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'floor'
        },
        id: {
          kind: 'identifier',
          name: 8
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'trunc'
        },
        id: {
          kind: 'identifier',
          name: 9
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'nearest'
        },
        id: {
          kind: 'identifier',
          name: 10
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'abs'
        },
        id: {
          kind: 'identifier',
          name: 11
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'neg'
        },
        id: {
          kind: 'identifier',
          name: 12
        }
      },
      {
        kind: 'export',
        name: {
          kind: 'literal',
          value: 'copysign'
        },
        id: {
          kind: 'identifier',
          name: 13
        }
      }
    ],
    [
      {
        index: 0,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'add',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      },
      {
        index: 1,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'sub',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      },
      {
        index: 2,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'mul',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      },
      {
        index: 3,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'div',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      },
      {
        index: 4,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'sqrt',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 5,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'min',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      },
      {
        index: 6,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'max',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      },
      {
        index: 7,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'ceil',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 8,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'floor',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 9,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'trunc',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 10,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'nearest',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 11,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'abs',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 12,
        bodySize: 4,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'unop',
          type: 'f64',
          operator: 'neg',
          expr: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          }
        }]
      },
      {
        index: 13,
        bodySize: 6,
        localCount: 0
      },
      {
        kind: 'func',
        body: [{
          kind: 'binop',
          type: 'f64',
          operator: 'copysign',
          left: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 0,
              raw: '0'
            }
          },
          right: {
            kind: 'get_local',
            id: {
              kind: 'literal',
              value: 1,
              raw: '1'
            }
          }
        }]
      }
    ],
    [
      {
        kind: 'name',
        id: 0,
        name: 'add'
      },
      {
        kind: 'name',
        id: 1,
        name: 'sub'
      },
      {
        kind: 'name',
        id: 2,
        name: 'mul'
      },
      {
        kind: 'name',
        id: 3,
        name: 'div'
      },
      {
        kind: 'name',
        id: 4,
        name: 'sqrt'
      },
      {
        kind: 'name',
        id: 5,
        name: 'min'
      },
      {
        kind: 'name',
        id: 6,
        name: 'max'
      },
      {
        kind: 'name',
        id: 7,
        name: 'ceil'
      },
      {
        kind: 'name',
        id: 8,
        name: 'floor'
      },
      {
        kind: 'name',
        id: 9,
        name: 'trunc'
      },
      {
        kind: 'name',
        id: 10,
        name: 'nearest'
      },
      {
        kind: 'name',
        id: 11,
        name: 'abs'
      },
      {
        kind: 'name',
        id: 12,
        name: 'neg'
      },
      {
        kind: 'name',
        id: 13,
        name: 'copysign'
      }
    ]
  ]
}
